==> lxqt-globalkeys_0.14.3.orig.tar.xz: lxqt-globalkeys-0.14.3/config/translations/lxqt-config-globalkeyshortcuts_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Príkaz</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Volanie DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Klávesová skratka</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Informácie</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Upraviť akciu</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Klávesová skratka:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Popis:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Aktívne</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Príkaz</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;Správa z DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>&amp;Príkaz:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>&amp;Služba:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Popis umiestnenia:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Rozhranie:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Metóda:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globálna sprava akcií</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="55"/>
        <source>Add ...</source>
        <translation>Pridať...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="65"/>
        <source>Remove</source>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="75"/>
        <source>Modify ...</source>
        <translation>Zmeniť...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Swap</source>
        <translation>Prehodiť</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="118"/>
        <source>Multiple actions behaviour:</source>
        <translation>Chovanie pri viacerých akciách:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="126"/>
        <source>First</source>
        <translation>Prvé</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="131"/>
        <source>Last</source>
        <translation>Posledné</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="136"/>
        <source>None</source>
        <translation>Žiadne</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="141"/>
        <source>All</source>
        <translation>Všetko</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="166"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="186"/>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="187"/>
        <source>Restore Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="188"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-globalkeys_0.15.0.orig.tar.xz: lxqt-globalkeys-0.15.0/config/translations/lxqt-config-globalkeyshortcuts_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Príkaz</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Volanie DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Klávesová skratka</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Informácie</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Upraviť akciu</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Klávesová skratka:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Popis:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Aktívne</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Príkaz</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;Správa z DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>&amp;Príkaz:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>&amp;Služba:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Popis umiestnenia:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Rozhranie:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Metóda:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globálna sprava akcií</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="55"/>
        <source>Add ...</source>
        <translation>Pridať...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="65"/>
        <source>Remove</source>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="75"/>
        <source>Modify ...</source>
        <translation>Zmeniť...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Swap</source>
        <translation>Prehodiť</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="118"/>
        <source>Multiple actions behaviour:</source>
        <translation>Chovanie pri viacerých akciách:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="126"/>
        <source>First</source>
        <translation>Prvé</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="131"/>
        <source>Last</source>
        <translation>Posledné</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="136"/>
        <source>None</source>
        <translation>Žiadne</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="141"/>
        <source>All</source>
        <translation>Všetko</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="166"/>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="186"/>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="187"/>
        <source>Restore Default</source>
        <translation>Vrátiť na východzie hodnoty</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="188"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Vami určené klávesové skratky budú odobrané
Naozaj to chcete?</translation>
    </message>
</context>
</TS>
